@@ -7,11 +7,18 @@ Created on 15-06-2013
 import sys
 
 class ArgUtils:
+    
+    def getStrings(name):  # @NoSelf
+        v = []
+        for i in range(len(sys.argv)):
+            if sys.argv[i] == "--" + name or sys.argv[i] == "-" + name:
+                v.append(sys.argv[i + 1].strip())
+        return v
 
     def getString(name, defaultvalue):  # @NoSelf
         for i in range(len(sys.argv)):
             if sys.argv[i] == "--" + name or sys.argv[i] == "-" + name:
-                return sys.argv[i + 1]
+                return sys.argv[i + 1].strip()
         return defaultvalue
     
     def isArgPresent(name):  # @NoSelf
